@@ -5,7 +5,7 @@ use warnings;
 use parent 'Perl::Critic::Policy';
 use Perl::Critic::Utils ':severities';
 
-$Perl::Critic::Policy::Variables::RequireHungarianNotation::VERSION = '0.0.4';
+$Perl::Critic::Policy::Variables::RequireHungarianNotation::VERSION = '0.0.5';
 
 sub desc {
     return 'Non hungarian notation';
@@ -17,19 +17,20 @@ sub expl {
 
 sub supported_parameters {
     return (
-        { name => 'array',     description => 'Prefix for Array vars',                     default_string => q/a_/, },
-        { name => 'hash',      description => 'Prefix for Hash vars',                      default_string => q/h_/, },
-        { name => 'array_ref', description => 'Prefix for Arrayref vars',                  default_string => q/ar_/, },
-        { name => 'hash_ref',  description => 'Prefix for Hashref vars',                   default_string => q/hr_/, },
-        { name => 'code_ref',  description => 'Prefix for Coderef vars',                   default_string => q/cr_/, },
-        { name => 'object',    description => 'Prefix for Object vars',                    default_string => q/o_/, },
-        { name => 'integer',   description => 'Prefix for Integer vars',                   default_string => q/i_/, },
-        { name => 'float',     description => 'Prefix for Float vars',                     default_string => q/f_/, },
-        { name => 'string',    description => 'Prefix for String vars',                    default_string => q/s_/, },
-        { name => 'boolean',   description => 'Prefix for boolean vars',                   default_string => q/b_/ },
-        { name => 'regex',     description => 'Prefix for predefined regular expressions', default_string => q/rx_/ },
-        { name => 'self',      description => 'Ingore self variable',                      default_string => q/self/ },
-        { name => 'custom',    description => 'Custom prefixes', },
+        { name => 'array',       description => 'Prefix for Array vars',                     default_string => q/a_/, },
+        { name => 'hash',        description => 'Prefix for Hash vars',                      default_string => q/h_/, },
+        { name => 'array_ref',   description => 'Prefix for Arrayref vars',                  default_string => q/ar_/, },
+        { name => 'hash_ref',    description => 'Prefix for Hashref vars',                   default_string => q/hr_/, },
+        { name => 'code_ref',    description => 'Prefix for Coderef vars',                   default_string => q/cr_/, },
+        { name => 'file_handle', description => 'Prefix for file handles',                   default_string => q/fh_/, },
+        { name => 'object',      description => 'Prefix for Object vars',                    default_string => q/o_/, },
+        { name => 'integer',     description => 'Prefix for Integer vars',                   default_string => q/i_/, },
+        { name => 'float',       description => 'Prefix for Float vars',                     default_string => q/f_/, },
+        { name => 'string',      description => 'Prefix for String vars',                    default_string => q/s_/, },
+        { name => 'boolean',     description => 'Prefix for boolean vars',                   default_string => q/b_/ },
+        { name => 'regex',       description => 'Prefix for predefined regular expressions', default_string => q/rx_/ },
+        { name => 'self',        description => 'Ingore self variable',                      default_string => q/self/ },
+        { name => 'custom',      description => 'Custom prefixes', },
     );
 }
 
@@ -47,7 +48,7 @@ sub applies_to {
 
 sub violates {
     my ( $self, $o_variable, undef ) = @_;
-    return if not scalar grep { $o_variable->type eq $_ } qw/my our local/;
+    return if not scalar grep { $o_variable->type eq $_ } qw/my our local state/;
     if ( $self->_violates_scalar($o_variable) || $self->_violates_list($o_variable) ) {
         return $self->violation( desc(), expl(), $o_variable );
     }
@@ -98,7 +99,7 @@ sub _check_sub_variables {
 sub _b_check_scalar {
     my ( $self, $s_symbol, $s_raw_type ) = @_;
     return 1 if $s_symbol eq q/$/ . $self->{_self};
-    for (qw/array_ref hash_ref object integer float string boolean regex code_ref/) {
+    for (qw/array_ref hash_ref object integer float string boolean regex code_ref file_handle/) {
         return 1 if $self->_check_prefix( $s_symbol, q/$/, $_ );
     }
     if ( $self->{_custom} ) {
@@ -110,6 +111,7 @@ sub _b_check_scalar {
 
 sub _b_check_list {
     my ( $self, $s_symbol, $s_raw_type ) = @_;
+    return 1 if $s_symbol =~ /\@ARGV/;
     for (qw/array hash/) {
         return 1 if $self->_check_prefix( $s_symbol, $s_raw_type, $_ );
     }
@@ -131,7 +133,7 @@ Perl::Critic::Policy::Variables::RequireHungarianNotation - Critic policy for hu
 
 =head1 VERSION
 
-Version 0.0.4
+Version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -205,8 +207,7 @@ Returns a string containing a sort description of this policy.
 
 =head1 INTERFACE 
 
-=for author to fill in:
-    L<Perl::Critic::Policy|Perl::Critic::Policy>
+L<Perl::Critic::Policy|Perl::Critic::Policy>
 
 =head1 DIAGNOSTICS
 
@@ -325,7 +326,7 @@ Mario Zieschang  C<< <mziescha -at - cpan -dot- org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2018, Mario Zieschang C<< <mziescha@cpan.org> >>. All rights reserved.
+Copyright (c) 2018, Mario Zieschang. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic|perlartistic>.
